==> bootstrap-simple-application-theme-4.1.0.tgz: package/webpack.config.js <==
// Set the event based on the npm script that is running (start, build, test, etc.)
// const npmEvent = process.env.npm_lifecycle_event;

// export the specific config for current process
// module.exports = require(`./conf/webpack.${npmEvent}.config.js`);
// 

const webpack = require('webpack');
const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const CleanWebpackPlugin = require('clean-webpack-plugin');

const config = {
    mode: "development",
    entry: [
        './src/js/app.js',
        './src/sass/app.scss'
    ],
    output: {
        path: path.resolve(__dirname, 'dist'),
        filename: 'app-theme.js',
        libraryTarget: 'umd'
    },
    module: {
        rules: [{
                test: /\.s?[ac]ss$/,
                use: [
                    MiniCssExtractPlugin.loader,
                    {
                        loader: 'css-loader', // translates CSS into CommonJS modules
                        options: {
                            sourceMap: true
                        }
                    },
                    {
                        loader: 'postcss-loader', // Run post css actions
                        options: {
                            sourceMap: true,
                            plugins: function() { // post css plugins, can be exported to postcss.config.js
                                return [
                                    require('postcss-flexbugs-fixes'),
                                    require('autoprefixer')
                                ];
                            }
                        }
                    },
                    {
                        loader: 'sass-loader', // compiles SASS to CSS
                        options: {
                            sourceMap: true
                        }
                    }
                ]
            },
            {
                test: /\.(png|jpg|gif|svg)$/,
                use: 'url-loader'
            },
            {
                test: /.html$/,
                use: {
                    loader: 'html-loader',
                    options: {
                        interpolate: true
                    }
                }
            },
            {
                test: /\.js$/,
                exclude: /node_modules/,
                use: [{
                    loader: 'babel-loader', // transpile to ES5
                    options: {
                        presets: ['es2015']
                    }
                }]
            }
        ]
    },
    plugins: [
        new CleanWebpackPlugin(['dist']),
        new MiniCssExtractPlugin({ // define where to save the file
            filename: "app-theme.css",
            chunkFilename: "[id].css"
        }),
        new HtmlWebpackPlugin({
            filename: 'index.html',
            template: './src/demo/html/index.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'elements.html',
            template: './src/demo/html/elements.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'sidebars.html',
            template: './src/demo/html/sidebars.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'clean.html',
            template: './src/demo/html/clean.html'
        })
    ]
};

module.exports = config;

==> bootstrap-simple-application-theme-5.1.0.tgz: package/webpack.config.js <==
// Set the event based on the npm script that is running (start, build, test, etc.)
// const npmEvent = process.env.npm_lifecycle_event;

// export the specific config for current process
// module.exports = require(`./conf/webpack.${npmEvent}.config.js`);
// 

const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const { CleanWebpackPlugin } = require('clean-webpack-plugin');

module.exports = {
    mode: "development",
    entry: [
        './src/app.js',
        // './src/sass/app.scss'
    ],
    output: {
        path: path.resolve(__dirname, 'dist'),
        filename: 'app-theme.js',
        libraryTarget: 'umd'
    },
    module: {
        rules: [
            {
                test: /\.s[ac]ss$/i,
                use: [
                    MiniCssExtractPlugin.loader,
                    "css-loader",
                    "sass-loader",
                ]
            },
            {
                test: /\.(png|jpg|gif|svg)$/,
                use: 'url-loader'
            },
            {
                test: /\.m?js$/,
                exclude: /(node_modules|bower_components)/,
                use: {
                    loader: 'babel-loader',
                    options: {
                        presets: ['@babel/preset-env']
                    }
                }
            }
        ],
    },
    plugins: [
        new CleanWebpackPlugin(),
        new MiniCssExtractPlugin({
          filename: "[name].css",
        }),
        new HtmlWebpackPlugin({
            filename: 'index.html',
            template: './src/demo/html/index.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'elements.html',
            template: './src/demo/html/elements.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'navbar.html',
            template: './src/demo/html/navbar.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'sidebars.html',
            template: './src/demo/html/sidebars.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'default.html',
            template: './src/demo/html/default.html'
        }),
        new HtmlWebpackPlugin({
            filename: 'clean.html',
            template: './src/demo/html/clean.html'
        })
    ]
}
